==> haskell-aeson-better-errors-0.9.1.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-GeIt2e4sXsC9wPJrRr2UNi
key: aeson-better-errors-0.9.1.0-GeIt2e4sXsC9wPJrRr2UNi
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: e7ecc3fddc52472730856f0382f3a0fa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-GeIt2e4sXsC9wPJrRr2UNi
depends:
    base-4.10.1.0 aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj bytestring-0.10.8.2
    scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=b98e175ed6b9bea3c0e69ce59165f686
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=94a5340d64a5db3506fe5654c7b40389
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=2129d94dd9a574dcd2d2bc46dca144d6
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-1jSE6Ekxr6qHLwdKcv4AmW
key: aeson-better-errors-0.9.1.0-1jSE6Ekxr6qHLwdKcv4AmW
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: d238d96c0b30eb3a1f30b2e391327998
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-1jSE6Ekxr6qHLwdKcv4AmW
depends:
    base-4.10.1.0 aeson-1.2.4.0-AtrYaitd3jMG1bjpyUF0Ei
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj bytestring-0.10.8.2
    scientific-0.3.6.2-2MF9INjgKxiGvbC0MBb5FD
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             aeson-1.2.4.0-AtrYaitd3jMG1bjpyUF0Ei=cd659b4105a2c797bfc8b13b8ea3a331
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=b98e175ed6b9bea3c0e69ce59165f686
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             scientific-0.3.6.2-2MF9INjgKxiGvbC0MBb5FD=b926dd2e2fb0b7b9106a4de9722f1bf6
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=94a5340d64a5db3506fe5654c7b40389
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=2129d94dd9a574dcd2d2bc46dca144d6
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
